==> libsearch-elasticsearch-perl_7.715.orig.tar.gz: Search-Elasticsearch-7.715/lib/Search/Elasticsearch/Client/7_0/Direct/Shutdown.pm <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

package Search::Elasticsearch::Client::7_0::Direct::Shutdown;
$Search::Elasticsearch::Client::7_0::Direct::Shutdown::VERSION = '7.715';
use Moo;
with 'Search::Elasticsearch::Client::7_0::Role::API';
with 'Search::Elasticsearch::Role::Client::Direct';
use namespace::clean;

__PACKAGE__->_install_api('shutdown');

1;

=pod

=encoding UTF-8

=head1 NAME

Search::Elasticsearch::Client::7_0::Direct::Shutdown - Plugin providing Shutdown feature for Search::Elasticsearch 7.x

=head1 VERSION

version 7.715

=head1 SYNOPSIS

    my $response = $es->shutdown->put_node(
        node_id => $node_id
    );

=head2 DESCRIPTION

This class extends the L<Search::Elasticsearch> client with an C<shutdown>
namespace, to support the experimental shutdown APIs.

=head1 AUTHOR

Enrico Zimuel <enrico.zimuel@elastic.co>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2021 by Elasticsearch BV.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

__END__

# ABSTRACT: Plugin providing Shutdown feature for Search::Elasticsearch 7.x

==> libsearch-elasticsearch-perl_8.00.orig.tar.gz: Search-Elasticsearch-8.00/lib/Search/Elasticsearch/Client/8_0/Direct/Shutdown.pm <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

package Search::Elasticsearch::Client::8_0::Direct::Shutdown;
$Search::Elasticsearch::Client::8_0::Direct::Shutdown::VERSION = '8.00';
use Moo;
with 'Search::Elasticsearch::Client::8_0::Role::API';
with 'Search::Elasticsearch::Role::Client::Direct';
use namespace::clean;

__PACKAGE__->_install_api('shutdown');

1;

=pod

=encoding UTF-8

=head1 NAME

Search::Elasticsearch::Client::8_0::Direct::Shutdown - Shutdown API of Search::Elasticsearch 8.x

=head1 VERSION

version 8.00

=head2 DESCRIPTION

The full documentation for Shutdown API is available here:
L<https://www.elastic.co/guide/en/elasticsearch/reference/current/node-lifecycle-api.html>

=head1 FOLLOW METHODS

=head2 C<follow()>

    my $response = $es->shutdown->get_node();

=head1 AUTHOR

Enrico Zimuel <enrico.zimuel@elastic.co>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2022 by Elasticsearch BV.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

__END__

# ABSTRACT: Shutdown API of Search::Elasticsearch 8.x
